@@ -89,7 +89,7 @@ class Wiki():
     namespaces_ids = None # map from canonical name to id
 
     def __init__(self, endpoint=None, throttle=1,
-        disable_ssl_certificate_validation=False
+        disable_ssl_certificate_validation=True
     ):
         ''' Create wiki client for given endpoint addres.  '''
         self._tokens = {}
