@@ -15,8 +15,8 @@ class ImportException(Exception):
 @action('import_poster')
 def import_poster(film_name, source='en'):
     ''' Імпортувати постер для статті, і додати його в шаблон фільму.
-        Перший параметр - назва статті фільму,
-        другий - 
+        Перший параметр - назва статті фільму.
+        другий - джерело. url або мовний код. Якщо мовний код - автора та 
     '''
     wiki = get_wiki()
     try:
